==> ifrit_3.2.5.orig.tar.gz: ifrit-3.2.5/shells/base/ibgrenderwindowsubject.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
  

#ifndef IBGRENDERWINDOWSUBJECT_H
#define IBGRENDERWINDOWSUBJECT_H


#include "ibgwindowsubject.h"


class iggRenderWindow;
class iggRenderWindowInteractor;


class ibgRenderWindowSubject : public ibgWindowSubject
{

	friend class iggRenderWindow;
	friend class iggRenderWindowInteractor;

public:

	static bool RenderOnFocus;

protected:

	ibgRenderWindowSubject(iggRenderWindow *owner);
	virtual ~ibgRenderWindowSubject();

	//
	//  RenderWindow methods
	//
	virtual void Initialize(bool show) = 0;
	virtual void SwapBuffers() = 0;

	virtual void SetBorder(bool) = 0;
	virtual void SetFullScreen(bool) = 0;
	virtual void MakeCurrent() = 0;

	virtual void* GetGenericWindowId() const = 0;
	virtual void SetWindowName(const iString &s) = 0;

	virtual void RenderIntoMemory(iImage &) = 0;
	virtual bool IsReadyForDumpingImage() = 0;

	//
	//  Render the scene
	//
	void Render();

	//
	//  RenderWindowInteractor methods
	//
	virtual int CreateTimer(int) = 0;
	virtual int DestroyTimer() = 0;

	void OnMouseMoveBody(int x, int y, int b);
	void OnMousePressBody(int x, int y, int b);
	void OnMouseReleaseBody(int x, int y, int b);
	void OnKeyPressBody(char k, int b);
	void OnTimerBody();

 	void OnWindowFocusInBody();
	void OnWindowFocusOutBody();
	void OnWindowEnterBody();
	void OnWindowLeaveBody();
	void OnWindowResizeBody();
    void OnWindowMoveBody();

	bool IsInteractorPresent();

	iggRenderWindow *mOwner;
	iggRenderWindowInteractor *mInteractor;
};

#endif //IBGRENDERWINDOWSUBJECT_H

==> ifrit_3.2.8.orig.tar.gz: ifrit-3.2.8/shells/base/ibgrenderwindowsubject.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
  

#ifndef IBGRENDERWINDOWSUBJECT_H
#define IBGRENDERWINDOWSUBJECT_H


#include "ibgwindowsubject.h"


class iggRenderWindow;
class iggRenderWindowInteractor;


class ibgRenderWindowSubject : public ibgWindowSubject
{

	friend class iggRenderWindow;
	friend class iggRenderWindowInteractor;

public:

	static bool RenderOnFocus;

protected:

	ibgRenderWindowSubject(iggRenderWindow *owner);
	virtual ~ibgRenderWindowSubject();

	//
	//  RenderWindow methods
	//
	virtual void Initialize(bool show) = 0;
	virtual void SwapBuffers() = 0;

	virtual void SetBorder(bool) = 0;
	virtual void SetFullScreen(bool) = 0;
	virtual void MakeCurrent() = 0;

	virtual void* GetGenericWindowId() const = 0;
	virtual void SetWindowName(const iString &s) = 0;

	virtual void RenderIntoMemory(iImage &) = 0;
	virtual bool IsReadyForDumpingImage() = 0;

	virtual bool IsCurrent() = 0;

	//
	//  Render the scene
	//
	void Render();

	//
	//  RenderWindowInteractor methods
	//
	virtual int InternalCreateTimer(int timerId, int timerType, unsigned long duration) = 0;
	virtual int InternalDestroyTimer(int platformTimerId) = 0;

	void OnMouseMoveBody(int x, int y, int b);
	void OnMousePressBody(int x, int y, int b);
	void OnMouseReleaseBody(int x, int y, int b);
	void OnKeyPressBody(char k, int b);
	void OnTimerBody();

 	void OnWindowFocusInBody();
	void OnWindowFocusOutBody();
	void OnWindowEnterBody();
	void OnWindowLeaveBody();
	void OnWindowResizeBody();
    void OnWindowMoveBody();

	bool IsInteractorPresent();

	iggRenderWindow *mOwner;
	iggRenderWindowInteractor *mInteractor;

private:

	bool mInRender;
};

#endif //IBGRENDERWINDOWSUBJECT_H
